@@ -1,13 +1,17 @@
 import traceback
 import importlib
 import logging
+import os
+
 from numerous_api_client.client import open_client
 
 logging.basicConfig(level=logging.DEBUG)
 log = logging.getLogger('numerous.main')
 log.setLevel(logging.DEBUG)
 
-def run(object_path):
+def run(object_path, workdir='.'):
+
+    os.chdir(workdir)
 
     #Open the numerous client
     with open_client() as client:
